<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lv">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>LXQt peles tēmas konfigurēšana</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Izvēlies kursora tēmu, kuru vēlies lietot (novieto kursoru uz priekšskata laukuma, lai izmēģinātu)&lt;b&gt;Pēc šīm izmaiņām LXQt sesija ir jārestartē&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="104"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Instalēt/uzstādīt/pievienot jaunu tēmu...</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="72"/>
        <source>LXQt session needs restart to view this change.</source>
        <translation>Šī iestatījuma maiņa stāsies spēkā pēc LXQt sesijas restarta.</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="111"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Dzēst/novākt tēmu</translation>
    </message>
    <message>
        <location filename="../selectwnd.ui" line="65"/>
        <source>Size:</source>
        <translation>Izmērs:</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="231"/>
        <source>XCurTheme error</source>
        <translation>XCurTheme ķibele</translation>
    </message>
    <message>
        <location filename="../selectwnd.cpp" line="232"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Aktīvo tēmu dzēst/novākt nav iespējams!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Forma</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>LXQt nespēja atrast nevienu kursora tēmu/motīvu. Tiks izmantota X11 noklusējuma kursora tēma. LXQt meklēja šajās mapēs:</translation>
    </message>
    <message>
        <location filename="../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Rādīt...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../thememodel.cpp" line="62"/>
        <source>Name</source>
        <translation>Nosaukums</translation>
    </message>
    <message>
        <location filename="../thememodel.cpp" line="63"/>
        <source>Description</source>
        <translation>Apraksts</translation>
    </message>
</context>
</TS>
